@@ -1,6 +1,6 @@
 from .shared import (
     validate_dates, validate_region_in_country, validate_country, need_validate_coordinates, validate_coordinates,
-    validate_area, need_validate_area, validate_date_lt_today, validate_is_region
+    validate_area, need_validate_area, validate_date_lt_today, validate_is_region, validate_area_size
 )
 
 
@@ -36,5 +36,6 @@ def validate_organisation(organisation: dict, node_map: dict = {}):
         validate_is_region(organisation) if 'region' in organisation else True,
         validate_region_in_country(organisation) if 'region' in organisation else True,
         validate_coordinates(organisation) if need_validate_coordinates(organisation) else True,
-        validate_area(organisation) if need_validate_area(organisation) else True
+        validate_area(organisation) if need_validate_area(organisation) else True,
+        validate_area_size(organisation)
     ]
