@@ -351,7 +351,12 @@ def _model_value(result, default_value=0):
 
 def _value_from_model(result):
     value = _model_value(result)
-    return list_sum(value, value)
+    try:
+        # fix numpy.float64
+        # TODO: find a better way to handle this
+        return list_sum(value, float(value))
+    except Exception:
+        return list_sum(value, value)
 
 
 def _parse_node_value(node: dict):
