@@ -3,7 +3,7 @@ import json
 from tests.utils import fixtures_path
 from hestia_earth.validation.utils import _group_nodes, _hash_nodes
 from hestia_earth.validation.validators.shared import (
-    validate_dates, validate_list_dates, validate_list_duplicates, validate_list_min_max,
+    validate_dates, validate_list_dates, validate_list_min_max,
     validate_country, validate_region_in_country, validate_is_region, validate_area, validate_coordinates,
     need_validate_coordinates, validate_list_term_percent, validate_empty_fields, validate_linked_source_privacy,
     validate_list_dates_length, validate_date_lt_today, validate_list_date_lt_today,
@@ -85,55 +85,6 @@ def test_validate_emissions_dates_invalid():
     }
 
 
-def test_validate_list_duplicates_valid():
-    node = {
-        'list': [{
-            'startDate': '2020-01-01',
-            'endDate': '2020-01-02',
-            'value': 1,
-            'nested': [{
-                'value': 1
-            }]
-        }, {
-            'startDate': '2020-01-01',
-            'endDate': '2020-01-02',
-            'value': 2,
-            'nested': [{
-                'value': 2
-            }]
-        }]
-    }
-    assert validate_list_duplicates(node, 'list', ['startDate', 'endDate', 'nested.value']) is True
-
-
-def test_validate_list_duplicates_invalid():
-    node = {
-        'list': [{
-            'startDate': '2020-01-01',
-            'endDate': '2020-01-02',
-            'value': 1,
-            'nested': [{
-                'value': 1
-            }]
-        }, {
-            'startDate': '2020-01-01',
-            'endDate': '2020-01-02',
-            'value': 2,
-            'nested': [{
-                'value': 1
-            }, {
-                'value': 2
-            }]
-        }]
-    }
-    assert validate_list_duplicates(node, 'list', ['startDate', 'endDate', 'nested.value']) == {
-        'level': 'error',
-        'dataPath': '.list[0]',
-        'message': 'Duplicates found. '
-        'Please make sure there is only one entry with the same startDate, endDate, nested.value'
-    }
-
-
 def test_validate_list_min_max_valid():
     node = {
         'list': [{
@@ -540,7 +491,7 @@ def test_validate_list_model_invalid():
                 'termType': 'emission'
             },
             'current': 200,
-            'expected': 157.100021417863,
+            'expected': 157.1,
             'delta': 27.310000000000002,
             'threshold': 0.05
         }
