@@ -12,7 +12,7 @@ fixtures_folder = f"{fixtures_path}/transformation"
 
 def test_validate_previous_transformation_valid():
     # no transformations should be valid
-    assert validate_previous_transformation([])
+    assert validate_previous_transformation([]) is True
 
     with open(f"{fixtures_folder}/previousTransformationTerm/valid.json") as f:
         data = json.load(f)
@@ -47,7 +47,7 @@ def test_validate_previous_transformation_invalid():
 
 def test_validate_first_transformation_valid():
     # no transformations should be valid
-    assert validate_first_transformation([])
+    assert validate_first_transformation([]) is True
 
     with open(f"{fixtures_folder}/first-transformation/valid.json") as f:
         data = json.load(f)
